///
///    This file is part of ILNumerics Community Edition.
///
///    ILNumerics Community Edition - high performance computing for applications.
///    Copyright (C) 2006 - 2012 Haymo Kutschbach, http://ilnumerics.net
///
///    ILNumerics Community Edition is free software: you can redistribute it and/or modify
///    it under the terms of the GNU General Public License version 3 as published by
///    the Free Software Foundation.
///
///    ILNumerics Community Edition is distributed in the hope that it will be useful,
///    but WITHOUT ANY WARRANTY; without even the implied warranty of
///    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
///    GNU General Public License for more details.
///
///    You should have received a copy of the GNU General Public License
///    along with ILNumerics Community Edition. See the file License.txt in the root
///    of your distribution package. If not, see <http://www.gnu.org/licenses/>.
///
///    In addition this software uses the following components and/or licenses: 
///
///    =================================================================================
///    The Open Toolkit Library License
///    
///    Copyright (c) 2006 - 2009 the Open Toolkit library.
///    
///    Permission is hereby granted, free of charge, to any person obtaining a copy
///    of this software and associated documentation files (the "Software"), to deal
///    in the Software without restriction, including without limitation the rights to 
///    use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
///    the Software, and to permit persons to whom the Software is furnished to do
///    so, subject to the following conditions:
///
///    The above copyright notice and this permission notice shall be included in all
///    copies or substantial portions of the Software.
///
///    =================================================================================
///    

using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;
using System.Drawing;
using ILNumerics.Drawing.Misc;  

namespace ILNumerics.Drawing.Misc {
    /// <summary>
    /// enumerate colors 
    /// </summary>
    public class ILColorEnumerator {

        List<Color> m_colors;
        int m_curPos; 

        /// <summary>
        /// create new color enumeration based on a specific colormap
        /// </summary>
        /// <param name="basemap"></param>
        public ILColorEnumerator(Colormaps basemap) {
            ILColormap cm = new ILColormap(basemap);
            m_colors = new List<Color>(); 
            for (int i = 0; i < cm.Length; i++) {
                m_colors.Add(cm.Map(i)); 
            }
            m_curPos = 0; 
        }
        /// <summary>
        /// create new color enumerator based on Colormap.Lines
        /// </summary>
        public ILColorEnumerator () : this (Colormaps.Lines) { }

        /// <summary>
        /// return next color and increase internal pointer
        /// </summary>
        /// <returns></returns>
        public Color NextColor() {
            Color ret = m_colors[m_curPos++]; 
            if (m_curPos == m_colors.Count) 
                m_curPos = 0;
            return ret; 
        }
    }
}
