///
///    This file is part of ILNumerics Community Edition.
///
///    ILNumerics Community Edition - high performance computing for applications.
///    Copyright (C) 2006 - 2012 Haymo Kutschbach, http://ilnumerics.net
///
///    ILNumerics Community Edition is free software: you can redistribute it and/or modify
///    it under the terms of the GNU General Public License version 3 as published by
///    the Free Software Foundation.
///
///    ILNumerics Community Edition is distributed in the hope that it will be useful,
///    but WITHOUT ANY WARRANTY; without even the implied warranty of
///    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
///    GNU General Public License for more details.
///
///    You should have received a copy of the GNU General Public License
///    along with ILNumerics Community Edition. See the file License.txt in the root
///    of your distribution package. If not, see <http://www.gnu.org/licenses/>.
///
///    In addition this software uses the following components and/or licenses: 
///
///    =================================================================================
///    The Open Toolkit Library License
///    
///    Copyright (c) 2006 - 2009 the Open Toolkit library.
///    
///    Permission is hereby granted, free of charge, to any person obtaining a copy
///    of this software and associated documentation files (the "Software"), to deal
///    in the Software without restriction, including without limitation the rights to 
///    use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
///    the Software, and to permit persons to whom the Software is furnished to do
///    so, subject to the following conditions:
///
///    The above copyright notice and this permission notice shall be included in all
///    copies or substantial portions of the Software.
///
///    =================================================================================
///    

using System;
using System.Collections.Generic;
using System.Text;
using System.Threading;

namespace ILNumerics.Drawing.Misc {
    public class ILZoomAction : ILAction {
        
        ILPoint3Df m_MinCornerStart;
        ILPoint3Df m_MinCornerEnd; 
        ILPoint3Df m_MaxCornerStart; 
        ILPoint3Df m_MaxCornerEnd; 
        ILActionRamp m_ramp; 
        int m_currentStep; 
        ILPanel m_panel; 

        public ILZoomAction(ILPoint3Df MinCornerStart,
                            ILPoint3Df MinCornerEnd,
                            ILPoint3Df MaxCornerStart,
                            ILPoint3Df MaxCornerEnd, 
                            ILActionRamp ramp,
                            ILPanel panel) 
        : base () {
            m_MaxCornerEnd = ILPoint3Df.Max(MinCornerEnd,MaxCornerEnd);
            m_MaxCornerStart = ILPoint3Df.Max(MinCornerStart,MaxCornerStart); 
            m_MinCornerEnd = ILPoint3Df.Min(MinCornerEnd,MaxCornerEnd);
            m_MinCornerStart = ILPoint3Df.Min(MinCornerStart,MaxCornerStart);
            m_ramp = ramp; 
            m_panel = panel; 
        }

        protected override void RunInternal(object parameter) {
            float x1 = m_MinCornerStart.X;
            float y1 = m_MinCornerStart.Y;
            float z1 = m_MinCornerStart.Z;
            float x2 = m_MaxCornerStart.X;
            float y2 = m_MaxCornerStart.Y;
            float z2 = m_MaxCornerStart.Z;
            float aMinX = m_MinCornerEnd.X - x1;
            float aMinY = m_MinCornerEnd.Y - y1;
            float aMinZ = m_MinCornerEnd.Z - z1;
            float aMaxX = m_MaxCornerEnd.X - x2;
            float aMaxY = m_MaxCornerEnd.Y - y2;
            float aMaxZ = m_MaxCornerEnd.Z - z2;
            foreach (ILActionRampElement elem in m_ramp) {
                if (m_canceled) return; 
                ILPoint3Df min = new ILPoint3Df(
                            x1 + aMinX * elem.Value,
                            y1 + aMinY * elem.Value,
                            z1 + aMinZ * elem.Value);
                ILPoint3Df max = new ILPoint3Df(
                            x2 + aMaxX * elem.Value,
                            y2 + aMaxY * elem.Value,
                            z2 + aMaxZ * elem.Value); 
                m_panel.Limits.Set(min,max);
                m_panel.Refresh(); 
                if (m_canceled) return; 
                Thread.Sleep((int)(elem.Duration * 1000)); 
            }


        }
    }
}
